% Inference example for sparse regression example using glm-ie.
% Exercises opts.outerExact.
%
% We use the Nordborg Flowering Time dataset from http://walnut.usc.edu/.
%   X is a binary matrix of 166 individuals x 5k SNPs selected by prior
%     knowledge
%   y is a real vector with flowering times between 21 and 200
%
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 August 03
clear all, close all

load regress, y = (y-mean(y))/std(y); [m,n] = size(X);                % get data

% Gaussian or non-Gaussian i.e. sparse weight prior
% select by uncommenting the desired one
% pot = @(s) potT(s,2);            % Student's t
% pot = @(s) potLaplace(s);        % Laplace
pot = @(s) potExpPower(s,1.3);   % Exponential Power family

% Numbers from Christoph
s2 = 0.0078;                                                          % variance
B = 1;  tau = 125;                                         % sparse weight prior

fprintf('Do sparse regression using a (sparse) '), str = func2str(pot);
fprintf('%s weight prior.\n',str(8:end))

%% Inference
opts.innerOutput = 1;
opts.outerOutput = 1;
opts.outerNiter = 3;     % Number of outer loop iterations
opts.outerMVM = 170;     % Lanczos steps
opts.outerExact = 1;     % Exact marginal variance computation
opts.innerMVM = 100;     % CG steps
opts.innerPLS = 'plsLBFGS'; % PLS algorithm 
[uinf,ga,z,Q,T] = vbidl(X,y,s2,B,pot,tau,opts);

%% Estimation
opt.nMVM = 250; opt.output = 1; opt.exactNewt = 1;
[uest,phi] = feval('plsTN',zeros(n,1),X,y,B,opt,s2,'penFromPot',pot,tau);

fprintf('residual in %%\n')
fprintf('inference  %1.3e%%, ',norm(X*uinf-y)/norm(y))
fprintf('estimation %1.3e%%, ',norm(X*uest-y)/norm(y))
fprintf('\b\b\n')