% P = potLogistic(s) - Logistic potential for classification
%
% pot(s) = 1/(1+exp(-s))
%
%   See also POTFUNCTIONS.M.
% (c) by Hannes Nickisch, MPI for Biological Cybernetics, 2010 July 26

function P = potLogistic(s)

P = zeros(numel(s),4);                          % log potential, -log(1+exp(-s))
P(:,1) = min(0,s) - log(1+exp(-abs(s)));                  % safe since abs(s)>=0
p = exp(P(:,1));
P(:,2) = 1-p;             % 1st derivative of log potential, exp(-s)/(1+exp(-s))
P(:,3) = p.*(p-1);     % 2nd derivative of log potential, -exp(-s)/(1+exp(-s))^2
P(:,4) = 1/2;